@@ -16,9 +16,9 @@ class Record:
         self.bool_exists = None
         self.bool_moderated = None
         self.bool_processed = None
-        self.fk_program = None
+        self.fki_program_id = None
         self.uint8_t_locale = None
-        self.fk_device = None
+        self.fki_device_id = None
 
     def from_json(self, data):
         if 'id' in data:
@@ -39,12 +39,12 @@ class Record:
             self.bool_moderated = data['bool_moderated']
         if 'bool_processed' in data:
             self.bool_processed = data['bool_processed']
-        if 'fk_program' in data:
-            self.fk_program = data['fk_program']
+        if 'fki_program_id' in data:
+            self.fki_program_id = data['fki_program_id']
         if 'uint8_t_locale' in data:
             self.uint8_t_locale = data['uint8_t_locale']
-        if 'fk_device' in data:
-            self.fk_device = data['fk_device']
+        if 'fki_device_id' in data:
+            self.fki_device_id = data['fki_device_id']
 
 
 class Position:
@@ -64,7 +64,7 @@ class Position:
         self.uint32_satellite_visible = None
         self.uint32_satellite_locked = None
         self.fk_record_id = None
-        self.fki_record = None
+        self.fki_record_id = None
 
     def from_json(self, data):
         if 'id' in data:
@@ -97,8 +97,8 @@ class Position:
             self.uint32_satellite_locked = data['uint32_satellite_locked']
         if 'fk_record_id' in data:
             self.fk_record_id = data['fk_record_id']
-        if 'fki_record' in data:
-            self.fki_record = data['fki_record']
+        if 'fki_record_id' in data:
+            self.fki_record_id = data['fki_record_id']
 
 
 class Weather:
@@ -114,6 +114,7 @@ class Weather:
         self.vchar_description = None
         self.vchar_icon = None
         self.fk_record_id = None
+        self.fki_record_id = None
 
     def from_json(self, data):
         if 'id' in data:
@@ -138,6 +139,8 @@ class Weather:
             self.vchar_icon = data['vchar_icon']
         if 'fk_record_id' in data:
             self.fk_record_id = data['fk_record_id']
+        if 'fki_record_id' in data:
+            self.fki_record_id = data['fki_record_id']
 
 
 class Storage:
@@ -211,6 +214,7 @@ class FramesManager:
         if response.status_code == 200:
             return response.json()
         else:
+            print('Failed with code:', response.status_code)
             return {'code': response.status_code}
 
     def get_record(self, pki: str) -> Record:
